function [] = draw_rings_and_shadow(ViewingAz, LightingAz, Oblateness, AxialTilt, FileName, x, y)

    % Work out the maximum vertical radius at this axial tilt
    RadiusAtAxialTilt    = maximum_radius_for_oblateness_and_tilt(Oblateness, AxialTilt);

    % And from that how long the shadow should be
    ShadowRadius         = RadiusAtAxialTilt / sin(AxialTilt * unitsratio('rad', 'deg'));

    % Now define the shadow in terms of polar coordinate angles
    ShadowAngles         = [90:270] * unitsratio('rad', 'deg');

    % And the radius for each angle
    Radii                = ShadowRadius ./ ...
                           sqrt((cos(ShadowAngles) .^ 2) + ...
                                (ShadowRadius .^ 2 * sin(ShadowAngles) .^ 2) ...
                                );

    % Now rotate the ellipse by the lighting angle
    RotatedAngles        = ShadowAngles - (LightingAz * unitsratio('rad', 'deg'));

    % And turn the polar coordinates into cartesian ones for plotting
    [x_shadow, y_shadow] = pol2cart(RotatedAngles, Radii);

    % Define the rings in terms of their edges, color and transparancy
    RingInnerEdge    = [1.10 1.16 1.205 1.23 1.275 1.32 1.35];
    RingOuterEdge    = [1.16 1.20 1.22  1.27 1.31  1.34 1.38];

    RingThickness    = (RingOuterEdge - RingInnerEdge) / 2;
    RingCentreRadius = (RingOuterEdge + RingInnerEdge) / 2;

    RingColour           = [0.3  0.2  0.25  0.3   0.25  0.2  0.25];
    RingTransparency     = [0.5  0.5  0.5   0.5   0.5   0.5   0.5];

    % Draw the rings, with the intersection of the shadow removed
    for i = 1:length(RingThickness)

        ring_handles(i) = draw_ring(RingThickness(i),    ...
                                    RingCentreRadius(i), ...
                                    RingColour(i),       ...
                                    RingTransparency(i), ...
                                    x_shadow, y_shadow);

    end

    % Set where we're lighting and looking from
    lightangle(LightingAz, AxialTilt);
    view(ViewingAz, 15);

    % And save it
    print('-dpng', '-r150', [FileName '.png']);

    % Delete the rings so we can use the same base image again without
    % redrawing it
    for i = 1:length(RingThickness)

        delete(ring_handles(i));

    end
    
end